@@ -7,6 +7,8 @@
 from __future__ import absolute_import, division
 from __future__ import print_function, unicode_literals
 
+import warnings
+
 from lxml import etree
 
 import myokit
@@ -14,7 +16,7 @@ import myokit.formats.mathml
 import myokit.formats.cellml as cellml
 import myokit.formats.cellml.v2
 
-from myokit.mxml import split
+from myokit.formats.xml import split
 
 
 def parse_file(path):
@@ -692,14 +694,15 @@ class CellMLParser(object):
         self._check_id(element)
 
         # Check allowed content
-        self._check_allowed_content(
-            element, ['unit'], ['name', 'base_units'], name)
+        self._check_allowed_content(element, ['unit'], ['name'], name)
 
         # Check the units definition has children
         children = element.findall(self._join('unit'))
         if not children:
-            raise CellMLParsingError(
-                'Defining new base units is not supported.', element)
+            warnings.warn(
+                'Unable to parse definition for units "' + str(name) + '",'
+                ' using `dimensionless instead. (Defining new base units is'
+                ' not supported.)')
 
         # Parse content
         myokit_unit = myokit.units.dimensionless
